//-*-C++-*- Header file for Extended Qt Classes
// Copyright (C) 1997 by John P. Weiss
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// This file is unreadable, because the comment-docifier is
// brainedead.  Try a "make srcdocs" to generate the
// HTML-documentation.
//
#ifndef _QExtended_h_
#define _QExtended_h_ 1
#include <qlcdnum.h>
#include <qlabel.h>






/**
  This is an extended version of the {\bf QLabel} widget.  It emits
  signals to indicate when it has been pressed or released.

  Inspired by code from version 2.0 of Sean Vyain's {\tt xcd} program.
  
  @memo Extended version of {\bf QLabel}.
  @see QeLCDNumber
  */
class QeLabel : public QLabel
{
	 //
	 Q_OBJECT

   public:
	 /**
	   Class constructor.  See the documentation for {\bf QLabel}.
	   @memo
	   */
	 QeLabel( QWidget* parent=0, const char* name=0, WFlags f=0 );
	 /**
	   Overloaded class constructor.  See the documentation for {\bf
	   QLabel}.
	   @memo
	   */
	 QeLabel( const char* text, QWidget* parent=0, const char* name=0,
			WFlags f=0 );

	 //
   signals:
	 /**
	   {\em Signal}
	   
	   Emitted when a mouse press occurs on the widget.
	   Emits the x- and y-coordinate of the mouse.
	   @memo [{\tt signal}]
	   */
	 void pressed(int,int);
	 /**
	   {\em Signal}
	   
	   Emitted when a mouse release occurs on the widget.
	   Emits the x- and y-coordinate of the mouse.
	   @memo [{\tt signal}]
	   */
	 void released(int,int);

   protected:
	 /**
	   Virtual method reimplemented from {\bf QWidget}.

	   @memo
	   */
	 void mousePressEvent( QMouseEvent *me );
	 /**
	   Virtual method reimplemented from {\bf QWidget}.

	   @memo
	   */
	 void mouseReleaseEvent( QMouseEvent *me );
};



/**
  This is an extended version of the {\bf QLCDNumber} widget.  It
  emits signals to indicate when it has been pressed or released.

  Inspired by code from version 2.0 of Sean Vyain's {\tt xcd} program.
  
  @memo Extended version of {\bf QLCDNumber}.
  @see QeLabel
  */
class QeLCDNumber : public QLCDNumber
{
	 //
	 Q_OBJECT

   public:
	 /**
	   Class constructor.  See the documentation for {\bf QLCDNumber}.
	   @memo
	   */
	 QeLCDNumber( QWidget* parent=0, const char* name=0 );
	 /**
	   Overloaded class constructor.  See the documentation for {\bf
	   QLCDNumber}.
	   @memo
	   */
	 QeLCDNumber( uint numDigits, QWidget* parent=0, const char* name=0);

	 //
   signals:
	 /**
	   {\em Signal}
	   
	   Emitted when a mouse press occurs on the widget.
	   Emits the x- and y-coordinate of the mouse.
	   @memo [{\tt signal}]
	   */
	 void pressed(int,int);
	 /**
	   {\em Signal}
	   
	   Emitted when a mouse release occurs on the widget.
	   Emits the x- and y-coordinate of the mouse.
	   @memo [{\tt signal}]
	   */
	 void released(int,int);

   protected:
	 /**
	   Virtual method reimplemented from {\bf QWidget}.

	   @memo
	   */
	 void mousePressEvent( QMouseEvent *me );
	 /**
	   Virtual method reimplemented from {\bf QWidget}.

	   @memo
	   */
	 void mouseReleaseEvent( QMouseEvent *me );
};



#endif // _QExtended_h_
//||||||||||||||||||||||||||||||||
//
// End
// 
